@@ -32,11 +32,12 @@ log = getLogger("service")
 
 
 class NDUCameraService(Thread):
-    def __init__(self, instance=None, config_dir="", handler=None, is_main_thread=True, extension_folder=None, config_file="", timestamp=""):
+    def __init__(self, instance=None, config_dir="", handler=None, is_main_thread=True, extension_folder=None, config_file="", timestamp="", updater=None):
         self.__is_main_thread = is_main_thread
         if instance is None:
             instance = {}
         super().__init__()
+        self.updater = updater
         self.__result_handler = handler
         self._ndu_gate_config_dir = config_dir
         self._ndu_config_file = config_file
@@ -392,12 +393,14 @@ class NDUCameraService(Thread):
             has_motion_kernel = self.__motion_kernel is not None
             results_for_preview = None
             for _frame_index, frame in self.video_source.get_frames():
-                if self.__result_handler.get_restart_required():
+                if self.__result_handler.get_restart_required() or self.updater.exit_required:
                     self._exit_requested = True
+                    '''
                     try:
                         cv2.destroyWindow(self._winname)
                     except:
                         pass
+                    '''
 
                 if self._exit_requested:
                     break
@@ -447,10 +450,13 @@ class NDUCameraService(Thread):
                         log.exception(e)
                         log.error("can not create CAMERA_CAPTURE")
 
-                if self.__max_frame_dim is not None:
-                    frame = image_helper.resize_if_larger(frame, self.__max_frame_dim)
-                if self.__min_frame_dim is not None:
-                    frame = image_helper.resize_if_smaller(frame, self.__min_frame_dim)
+                if constants.MOBILE_RUNNER in self.available_runners:
+                    frame = image_helper.resize(frame, 320, 320)
+                else:
+                    if self.__max_frame_dim is not None:
+                        frame = image_helper.resize_if_larger(frame, self.__max_frame_dim)
+                    if self.__min_frame_dim is not None:
+                        frame = image_helper.resize_if_smaller(frame, self.__min_frame_dim)
 
                 if self.__preview_show:
                     results_for_preview = []
@@ -498,9 +504,9 @@ class NDUCameraService(Thread):
                                 empty_resulted_runners.append(runner_unique_key)
                             if self.__preview_show:
                                 elapsed = time.time() - start_time
+                                #self.__result_handler.save_result([{'data': {runner_conf["type"]: (1.0 / max(elapsed, 0.001))}}], device=device, runner_name=runner_conf["type"])
                                 results_for_preview.append({"elapsed_time": '{}: {:.4f}sn fps:{:.0f}'.format(
                                     runner_conf["type"], elapsed, 1.0 / max(elapsed, 0.001))})
-
                         except Exception as e:
                             log.exception(e)
 
@@ -540,6 +546,9 @@ class NDUCameraService(Thread):
                             self.__total_elapsed_times = []
                         results_for_preview.append({"total_elapsed_time": '{:.0f}msec fps:{:.0f}'.format(
                             total_elapsed_time * 1000, (1.0 / max(total_elapsed_time, 0.001)))})
+                        # self.__result_handler.save_result(
+                        #     [{'data': {'fps':  (1.0 / max(total_elapsed_time, 0.001))}}], device=device,
+                        #     runner_name=runner_conf["type"])
                         preview = self._get_preview(frame, results_for_preview)
                         if self.__preview_show_motion_kernel and last_thresh is not None:
                             th = image_helper.resize(last_thresh, preview.shape[1], preview.shape[0],
