@@ -14,6 +14,7 @@ from threading import Lock
 import requests
 import shutil
 
+
 class ResultHandlerMqtt:
     '''
         Cihaz verilerinin NDU platformuna MQTT APİ üzerinden gönderilmesi
@@ -38,9 +39,12 @@ class ResultHandlerMqtt:
         self.disconnected_data = []
         self.plate_service_url = plate_service_url
         self.frame = {}
+        self.frames_path = ""
         self.restart_required = False
         self.save_lock = Lock()
         self.frame_lock = Lock()
+        self.url = ""
+        self.http_topic = mqtt_obj.get("http_topic", "api/v1/")
         # Connect to ThingsBoard using default MQTT port and 60 seconds keepalive interval
         try:
             self.client.connect(host, mqtt_obj.get("port"), 5)
@@ -59,7 +63,7 @@ class ResultHandlerMqtt:
         with self.frame_lock:
             if device_name not in self.frame and self.platform:
                 self.frame.update({device_name: frame})
-                self.post_frame('send_frame-'+device_name)
+                self.post_frame('send_frame-' + device_name)
             else:
                 self.frame.update({device_name: frame})
 
@@ -81,8 +85,12 @@ class ResultHandlerMqtt:
         if 'shared' in obj:
             obj = obj['shared']
 
+        if 'device' in obj:
+            self.update_camera_configuration(obj)
+
         if constants.CONFIGURATION_KEY in obj:
             curr = yaml.safe_load(open(self.config_file))
+            obj = self.remove_custom_runners(obj)
             if curr != obj[constants.CONFIGURATION_KEY] and len(obj[constants.CONFIGURATION_KEY]['instances']) > 0:
                 with open(self.config_file, 'w',
                           encoding='utf-8') as f:
@@ -93,10 +101,30 @@ class ResultHandlerMqtt:
         if message.retain == 1:
             print("This is a retained message")
 
+    def remove_custom_runners(self, obj):
+        keys_to_remove = []
+        for instance in obj[constants.CONFIGURATION_KEY]['instances']:
+            for idx, runner in enumerate(instance['runners']):
+                if runner['configuration'].startswith('custom'):
+                    print(instance['runners'][idx])
+                    keys_to_remove.append(instance['runners'][idx])
+
+        for key in keys_to_remove:
+            for instance in obj[constants.CONFIGURATION_KEY]['instances']:
+                for idx, runner in enumerate(instance['runners']):
+                    if runner == key:
+                        del instance['runners'][idx]
+
+        return obj
+
     def check_frame(self, obj):
-        for k in obj:
-            if constants.SEND_FRAME in k:
-                return k
+        # for k in obj:
+        #     if constants.SEND_FRAME in k:
+        #         return k
+        if 'data' in obj.keys():
+            for k in obj['data']:
+                if constants.SEND_FRAME in k:
+                    return k
 
     def get_restart_required(self):
         return self.restart_required
@@ -107,6 +135,41 @@ class ResultHandlerMqtt:
                 return k
         return None
 
+    def update_camera_configuration(self, obj):
+        try:
+            if list(obj['data'].keys())[0].endswith('.json') and list(obj['data'].keys())[0].startswith(
+                    'custom') is False:
+                runner_conf = list(obj['data'].keys())[0]
+                data = obj['data'][runner_conf]
+                config_dir = Path(self.config_file).parent
+                with open(os.path.join(config_dir, runner_conf), 'r+') as file:
+                    d = json.load(file)
+                    if 'object_counter' in runner_conf:
+                        d['gates'] = data['gates']
+                        for value in d['classes'].keys():
+                            s = value
+                        d['classes'][s] = data['classes']
+                    elif 'intersector' in runner_conf:
+                        d['groups'][list(d['groups'])[0]]['obj_detection']['ground'] = data['ground']
+                        d['groups'][list(d['groups'])[0]]['obj_detection']['dist'] = data['dist']
+                        d['groups'][list(d['groups'])[0]]['obj_detection']['rects'][0]['class_names'] = data[
+                            'class_names']
+                    elif 'objects_in_area' in runner_conf:
+                        d['areas'] = data['areas']
+                        d['classes'] = data['classes']
+                    elif 'point_occupied' in runner_conf:
+                        d['points'] = data
+
+                    with open(os.path.join(config_dir, runner_conf), 'w') as file:
+                        print('File opened')
+                        json.dump(d, file, indent=4)
+                        self.restart_required = True
+                        self.dispose()
+        except Exception as e:
+            print(e)
+            self.create_default_conf(runner_conf)
+            self.update_camera_configuration(obj)
+
     def update_runner_configuration(self, runner_conf, obj):
         data = obj[runner_conf]
         config_dir = Path(self.config_file).parent
@@ -149,21 +212,26 @@ class ResultHandlerMqtt:
             item = item.split('.')[0]
             if item in runner_conf and extension == 'json':
                 try:
-                    shutil.copy(os.path.join(config_path, item+'.'+extension), os.path.join(config_path, runner_conf))
+                    shutil.copy(os.path.join(config_path, item + '.' + extension),
+                                os.path.join(config_path, runner_conf))
                 except shutil.SameFileError:
                     print("Source and destination represents the same file.")
 
     def post_frame(self, f):
-        device_name = f[len(constants.SEND_FRAME)+1:]
+        device_name = f[len(constants.SEND_FRAME) + 1:]
         headers = {
             'Content-Type': 'application/json',
         }
-        #self.frame_lock.acquire()
+        # self.frame_lock.acquire()
         label = ''.join(device_name.split())
         try:
-            data = '{frame_' + label+': "' + self.frame[device_name] + '"}'
-            #self.frame_lock.release()
-            response = requests.post('http://' + self.host + ':8080/api/v1/' + self.access_token + '/attributes',
+            data = '{frame_' + label + ': "' + self.frame[device_name] + '"}'
+            # self.frame_lock.release()
+            # mqtt_data = {
+            #     device_name: data
+            # }
+            # self.client.publish('v1/gateway/attributes', json.dumps(mqtt_data), 1)
+            response = requests.post('http://' + self.host + '/api/v1/' + self.access_token + '/attributes',
                                      headers=headers, data=data)
         except Exception as e:
             print(e)
@@ -271,6 +339,57 @@ class ResultHandlerMqtt:
             f = open(filename, 'w+')
         return result_list
 
+    def save_frames_locally(self, base64frame, device):
+        import base64, datetime
+        from os import path
+        from ndu_gate_camera.utility import image_helper
+        device = device.replace(" ", "-")
+        device = device.replace("_", "-")
+        if self.frames_path == "":
+            config = yaml.safe_load(open(self.config_file))
+            if config.get("frames_path") is None:
+                return
+            self.frames_path = config["frames_path"]
+            image_helper.set_frames_path(self.frames_path)
+
+        if image_helper.get_size(self.frames_path) > 5000000000:  # 5000000000
+            dir_list = next(os.walk(self.frames_path))[1]
+            dir_list.sort()
+            shutil.rmtree(self.frames_path + path.sep + dir_list[0])
+        # check frame number, if > 10000, create video
+        elif image_helper.get_frames_number() > 1000:
+            image_helper.create_video()
+        else:
+            date = str(datetime.datetime.now().strftime("%Y-%m-%d"))
+
+            if not os.path.exists(self.frames_path + path.sep + date):
+                os.makedirs(self.frames_path + path.sep + date)
+
+            if not os.path.exists(self.frames_path + path.sep + date + path.sep + device):
+                os.makedirs(self.frames_path + path.sep + date + path.sep + device)
+
+            with open(os.path.join(self.frames_path + path.sep + date + path.sep + device, device + '_' + str(datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S")).replace(":", "-") + image_helper.frame_extension), "wb") as fh:
+                fh.write(base64.b64decode(base64frame))
+                fh.close()
+
+    def send_frame_http(self, frame, device):
+        headers = {
+            'Content-Type': 'application/json',
+        }
+        device = device.replace(" ", "_")
+        data = '{frame_' + device + ': "' + frame + '"}'
+
+        try:
+            self.save_frames_locally(frame, device)
+            if self.url == "":
+                r = requests.get("http://" + self.host)
+                self.url = r.url
+            response = requests.post(self.url + self.http_topic + self.access_token + "/attributes",
+                                     headers=headers, data=data)
+            # print(response)
+        except Exception as e:
+            print(e)
+
     def send_telemetry(self, device, results):
         try:
             mqtt_data = {
@@ -290,14 +409,10 @@ class ResultHandlerMqtt:
                 single_data = {}
                 for key in data:
                     if data[key] is not None:
-                        # if key == "frame":
-                        #     #self.send_attribute(device, results)
-                        #     #self.send_frame(device, data)
-                        #     #await asyncio.run(self.send_frame(device, data))
-                        #     #asyncio.create_task(self.send_frame(device, data))
-                        #     self.save_result([{"data": {"frame": data[key]}}], device=device, data_type='attribute')
-                        # else:
-                        single_data[key] = data[key]
+                        if key == "frame":
+                            self.send_frame_http(data[key], device)
+                        else:
+                            single_data[key] = data[key]
 
                 mqtt_data[device].append(single_data)
                 if self.plate_service_url is not None:
