@@ -14,6 +14,7 @@ from ndu_gate_camera.camera.ndu_logger import NDULoggerHandler
 from ndu_gate_camera.camera.result_handlers.result_handler_file import ResultHandlerFile
 from ndu_gate_camera.camera.result_handlers.result_handler_socket import ResultHandlerSocket
 from ndu_gate_camera.camera.result_handlers.result_handler_mqtt import ResultHandlerMqtt
+from ndu_gate_camera.updater import Updater
 from ndu_gate_camera.utility import onnx_helper
 from ndu_gate_camera.utility.constants import DEFAULT_NDU_GATE_CONF, DEFAULT_NDU_GATE_CONF_WIN, DEFAULT_HANDLER_SETTINGS
 from ndu_gate_camera.utility.ndu_utility import NDUUtility
@@ -101,7 +102,7 @@ def main(ndu_gate_config_file):
             result_hand_conf = DEFAULT_HANDLER_SETTINGS
 
         res_handler = result_hand_conf.get("type")
-
+        updater = Updater()
         if str(res_handler) == str("SOCKET"):
             result_handler = ResultHandlerSocket(result_hand_conf.get("socket", {}),
                                                  result_hand_conf.get("device", None))
@@ -123,7 +124,7 @@ def main(ndu_gate_config_file):
                     preview_exists = True
                 camera_service = NDUCameraService(instance=instance, config_dir=ndu_gate_config_dir,
                                                   handler=result_handler, is_main_thread=False,
-                                                  extension_folder=extension_folder, config_file=ndu_gate_config_file, timestamp=timestamp)
+                                                  extension_folder=extension_folder, config_file=ndu_gate_config_file, timestamp=timestamp, updater=updater)
                 camera_service.start()
                 services.append(camera_service)
                 log.info("NDU-Gate an instance started")
@@ -146,13 +147,19 @@ def main(ndu_gate_config_file):
         elif len(instances) == 1 and instances[0]["source"].get("ignore", True) is False:
             camera_service = NDUCameraService(instance=instances[0], config_dir=ndu_gate_config_dir,
                                               handler=result_handler, is_main_thread=True,
-                                              extension_folder=extension_folder, config_file=ndu_gate_config_file, timestamp=timestamp)
+                                              extension_folder=extension_folder, config_file=ndu_gate_config_file, timestamp=timestamp, updater=updater)
             camera_service.run()
         else:
             log.error("NDUCameraService no source found!")
 
         log.info("NDUCameraService exiting...")
+        import subprocess
+        if updater.exit_required:
+            os.system("TASKKILL /F /IM ndugateapp.exe")
+            file_dir = os.path.dirname(os.path.realpath(__file__))
+            subprocess.Popen([os.path.join(file_dir, 'ndu_gate_update.exe'), '/SILENT'])
         if result_handler.get_restart_required():
+            result_handler.dispose()
             main(ndu_gate_config_file)
 
     except Exception as e:
