@@ -110,7 +110,8 @@ def fill_polyline_transparent(image, pnts, color, opacity, thickness=-1):
     cv2.copyTo(res, None, image)
 
 
-def select_areas(frame, window_name, color=(0, 0, 255), opacity=0.3, thickness=4, max_count=None, next_area_key="n", finish_key="s", return_tuples=True, max_point_count=None):
+def select_areas(frame, window_name, color=(0, 0, 255), opacity=0.3, thickness=4, max_count=None, next_area_key="n",
+                 finish_key="s", return_tuples=True, max_point_count=None):
     try:
         areas = []
         area = []
@@ -230,6 +231,8 @@ def select_points(frame, window_name, color=(0, 255, 255), radius=8, thickness=4
 
 
 def put_text(img, text_, center, color=None, font_scale=0.5, thickness=1, back_color=None, replace_tur_chars=True):
+    if len(text_) > 50:
+        return
     if replace_tur_chars:
         text_ = NDUUtility.debug_replace_tur_chars(text_)
     if back_color is None:
@@ -270,6 +273,16 @@ def normalize_coordinates(image, coords):
     return pnts
 
 
+def normalize_multiple_coordinates(image, coords):
+    h, w = image.shape[:2]
+    pnts = []
+    for coord in coords:
+        for x, y in coord:
+            pnts.append((x / w, y / h))
+
+    return pnts
+
+
 def denormalize_coordinates(image, coords):
     h, w = image.shape[:2]
     pnts = []
@@ -277,6 +290,7 @@ def denormalize_coordinates(image, coords):
         pnts.append((int(x * w), int(y * h)))
     return pnts
 
+
 def denormalize_coordinates_intersector(image, coords):
     h, w = image.shape[:2]
     pnts = []
@@ -284,6 +298,7 @@ def denormalize_coordinates_intersector(image, coords):
         pnts.append([int(x * w), int(y * h)])
     return pnts
 
+
 def normalize_coordinates_intersector(image, coords):
     h, w = image.shape[:2]
     pnts = []
@@ -291,6 +306,7 @@ def normalize_coordinates_intersector(image, coords):
         pnts.append([x / w, y / h])
     return pnts
 
+
 def normalize_lines(image, lines):
     lines1 = []
     for line in lines:
@@ -396,3 +412,102 @@ def adaptive_equalize_hist_bgr(img):
     # img[:, :, 1] = clahe.apply(img[:, :, 1])
     # img[:, :, 2] = clahe.apply(img[:, :, 2])
     # return img
+
+
+path_file = ""
+frame_extension = ".jpg"
+
+
+def set_frames_path(_path):
+    import os, shutil
+    from os import path
+    global path_file
+    path_file = _path
+    if not os.path.exists(path_file):
+        os.makedirs(path_file)
+    # create video using old, remained frames
+    create_video()
+    # size check
+    if get_size(path_file) > 5000000000:  # 5000000000
+        dir_list = next(os.walk(path_file))[1]
+        dir_list.sort()
+        shutil.rmtree(path_file + path.sep + dir_list[0])
+
+
+def get_frames_number():
+    from os import walk
+    global path_file
+    filenames = next(walk(path_file), (None, None, []))[2]  # [] if no file
+    filenames = [f for f in filenames if f.endswith(frame_extension)]
+    return len(filenames)
+
+
+def create_video():
+    import cv2
+    import os
+    from os import path
+    from os import walk
+    global path_file
+    dates = get_immediate_subdirectories(path_file)
+    for date_dir in dates:
+        cameras = get_immediate_subdirectories(path_file + path.sep + date_dir)
+        for camera in cameras:
+            frames = []
+            filenames = next(walk(path_file + path.sep + date_dir + path.sep + camera), (None, None, []))[2]  # [] if no file
+            # remove if file does not end with frame extension
+            filenames = [f for f in filenames if f.endswith(frame_extension)]
+            filenames.sort()
+            for filename in filenames:
+                if filename.endswith(frame_extension):
+                    frames.append(cv2.imread(path_file + path.sep + date_dir + path.sep + camera + path.sep + filename))
+            if len(frames) > 1:
+                height, width, _ = frames[0].shape
+                first_frame_name = filenames[0][:-4].replace(" ", "_").replace(":", ".")
+                last_frame_name = filenames[-1][:-4].replace(" ", "_").replace(":", ".")
+                device = first_frame_name.split("_")[0]
+                date = first_frame_name.split("_")[1]
+
+                if not os.path.exists(path_file + path.sep + date):
+                    os.makedirs(path_file + path.sep + date)
+
+                if not os.path.exists(path_file + path.sep + date + path.sep + device):
+                    os.makedirs(path_file + path.sep + date + path.sep + device)
+
+                first_name = first_frame_name.split("_")[1] + "_" + first_frame_name.split("_")[2]
+                last_name = last_frame_name.split("_")[1] + "_" + last_frame_name.split("_")[2]
+
+                out = cv2.VideoWriter(
+                    path_file + path.sep + date + path.sep + device + path.sep +
+                    first_name + '--' +
+                    last_name + ".mp4",
+                    cv2.VideoWriter_fourcc('m', 'p', '4', 'v'),
+                    1, (width, height))
+                [out.write(f) for f in frames]
+                out.release()
+
+            # delete frames
+            for filename in filenames:
+                if filename.endswith(frame_extension):
+                    try:
+                        os.remove(path_file + path.sep + date_dir + path.sep + camera + path.sep + filename)
+                    except:
+                        pass
+
+
+def get_size(start_path='.'):
+    import os
+    total_size = 0
+    for dirpath, dirnames, filenames in os.walk(start_path):
+        for f in filenames:
+            fp = os.path.join(dirpath, f)
+            # skip if it is symbolic link
+            if not os.path.islink(fp):
+                total_size += os.path.getsize(fp)
+
+    return total_size
+
+
+def get_immediate_subdirectories(a_dir):
+    import os
+    return [name for name in os.listdir(a_dir)
+            if os.path.isdir(os.path.join(a_dir, name))]
